##
##  libraw.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         libraw
Summary:      RAW Images Decoder Library
URL:          http://www.libraw.org/
Vendor:       Dave Coffin, Alex Tutubalin, Illiah Borg
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Graphics
License:      GPL
Version:      0.21.3
Release:      20240919

#   list of sources
Source0:      http://www.libraw.org/data/LibRaw-%{version}.tar.gz
Patch0:       libraw.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes
PreReq:       OpenPKG, openpkg >= 20160101

%description
    LibRaw is a library for reading RAW files from digital photo
    cameras (CRW/CR2, NEF, RAF, DNG, MOS, KDC, DCR, etc.; virtually all
    RAW formats are supported). It pays special attention to correct
    retrieval of data required for subsequent RAW conversion. The
    library is intended for embedding in RAW converters, data analyzers,
    and other programs using RAW files as the initial data.

%track
    prog libraw = {
        version   = %{version}
        url       = http://www.libraw.org/download
        regex     = LibRaw-(\d+\.\d+\.\d+)\.tar\.gz
    }

%prep
    %setup -q -n LibRaw-%{version}
    %patch -p0

%build
    CC="%{l_cc}" \
    CXX="%{l_cxx}" \
    CFLAGS="%{l_cflags -O}" \
    CXXFLAGS="%{l_cxxflags -O} -Wno-deprecated-declarations" \
    ./configure \
        --prefix=%{l_prefix} \
        --disable-shared
    %{l_make} %{l_mflags}

%install
    %{l_make} %{l_mflags} install DESTDIR="$RPM_BUILD_ROOT"
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

